@@ -1,5 +1,8 @@
 import disnake
 
+async def dummy_response(interaction):
+    await interaction.response.send_message("You are not the sender of that command!", ephemeral=True)
+
 class ButtonPaginator:
     def __init__(
             self,
@@ -11,13 +14,13 @@ class ButtonPaginator:
             target_page=1,
             timeout=300,
             button_style=disnake.ButtonStyle.gray,
-            invalid_user_text="You are not the sender of that command!",
+            invalid_user_function=dummy_response,
         ):
         self.embeds = []
         self.current_page = target_page
         self.timeout = timeout
         self.button_style = button_style
-        self.invalid_user_text = invalid_user_text
+        self.invalid_user_function = invalid_user_function
 
         for segment in segments:
             if isinstance(segment, disnake.Embed):
@@ -56,7 +59,7 @@ class ButtonPaginator:
             @disnake.ui.button(emoji="⏪", style=self.button_style, disabled=True if len(self.embeds) == 1 else False)
             async def first_button(this, _, button_interaction):
                 if button_interaction.author != this.interaction.author:
-                    await button_interaction.response.send_message(self.invalid_user_text, ephemeral=True)
+                    await self.invalid_user_function(button_interaction)
                     return
 
                 if len(self.embeds) >= 15:
@@ -73,7 +76,7 @@ class ButtonPaginator:
             @disnake.ui.button(emoji="◀️", style=self.button_style, disabled=True if len(self.embeds) == 1 else False)
             async def previous_button(this, _, button_interaction):
                 if button_interaction.author != this.interaction.author:
-                    await button_interaction.response.send_message(self.invalid_user_text, ephemeral=True)
+                    await self.invalid_user_function(button_interaction)
                     return
 
                 self.current_page -= 1
@@ -89,7 +92,7 @@ class ButtonPaginator:
             @disnake.ui.button(emoji="▶️", style=self.button_style, disabled=True if len(self.embeds) == 1 else False)
             async def next_button(this, _, button_interaction):
                 if button_interaction.author != this.interaction.author:
-                    await button_interaction.response.send_message(self.invalid_user_text, ephemeral=True)
+                    await self.invalid_user_function(button_interaction)
                     return
 
                 self.current_page += 1
@@ -101,7 +104,7 @@ class ButtonPaginator:
             @disnake.ui.button(emoji="⏩", style=self.button_style, disabled=True if len(self.embeds) == 1 else False)
             async def last_button(this, _, button_interaction):
                 if button_interaction.author != this.interaction.author:
-                    await button_interaction.response.send_message(self.invalid_user_text, ephemeral=True)
+                    await self.invalid_user_function(button_interaction)
                     return
 
                 if len(self.embeds) >= 15:
